gi-gtk-3.0.12: Gtk bindings

CopyrightWill Thompson, Iñaki García Etxebarria and Jonas Platte
LicenseLGPL-2.1
MaintainerIñaki García Etxebarria (garetxe@gmail.com)
Safe HaskellNone
LanguageHaskell2010

GI.Gtk.Structs.TextAttributes

Contents

Description

Using TextAttributes directly should rarely be necessary. It’s primarily useful with textIterGetAttributes. As with most GTK+ structs, the fields in this struct should only be read, never modified directly.

Synopsis

Exported types

newtype TextAttributes Source #

Instances

BoxedObject TextAttributes Source # 
(~) AttrOpTag tag AttrSet => Constructible TextAttributes tag Source # 
((~) * info (ResolveTextAttributesMethod t TextAttributes), MethodInfo * info TextAttributes p) => IsLabel t (TextAttributes -> p) Source # 

Methods

fromLabel :: Proxy# Symbol t -> TextAttributes -> p #

((~) * info (ResolveTextAttributesMethod t TextAttributes), MethodInfo * info TextAttributes p) => IsLabelProxy t (TextAttributes -> p) Source # 
HasAttributeList * TextAttributes Source # 
((~) * signature (m ()), MonadIO m) => MethodInfo * TextAttributesUnrefMethodInfo TextAttributes signature Source # 
((~) * signature (m TextAttributes), MonadIO m) => MethodInfo * TextAttributesRefMethodInfo TextAttributes signature Source # 
((~) * signature (TextAttributes -> m ()), MonadIO m) => MethodInfo * TextAttributesCopyValuesMethodInfo TextAttributes signature Source # 
((~) * signature (m TextAttributes), MonadIO m) => MethodInfo * TextAttributesCopyMethodInfo TextAttributes signature Source # 
type AttributeList TextAttributes Source # 

newZeroTextAttributes :: MonadIO m => m TextAttributes Source #

Construct a TextAttributes struct initialized to zero.

Methods

copy

textAttributesCopy Source #

Arguments

:: (HasCallStack, MonadIO m) 
=> TextAttributes

src: a TextAttributes to be copied

-> m TextAttributes

Returns: a copy of src, free with textAttributesUnref

Copies src and returns a new TextAttributes.

copyValues

textAttributesCopyValues Source #

Arguments

:: (HasCallStack, MonadIO m) 
=> TextAttributes

src: a TextAttributes

-> TextAttributes

dest: another TextAttributes

-> m () 

Copies the values from src to dest so that dest has the same values as src. Frees existing values in dest.

new

textAttributesNew Source #

Arguments

:: (HasCallStack, MonadIO m) 
=> m TextAttributes

Returns: a new TextAttributes, free with textAttributesUnref.

Creates a TextAttributes, which describes a set of properties on some text.

ref

textAttributesRef Source #

Arguments

:: (HasCallStack, MonadIO m) 
=> TextAttributes

values: a TextAttributes

-> m TextAttributes

Returns: the TextAttributes that were passed in

Increments the reference count on values.

unref

textAttributesUnref Source #

Arguments

:: (HasCallStack, MonadIO m) 
=> TextAttributes

values: a TextAttributes

-> m () 

Decrements the reference count on values, freeing the structure if the reference count reaches 0.

Properties

appearance

bgFullHeight

direction

editable

font

getTextAttributesFont :: MonadIO m => TextAttributes -> m (Maybe FontDescription) Source #

setTextAttributesFont :: MonadIO m => TextAttributes -> Ptr FontDescription -> m () Source #

fontScale

indent

invisible

justification

language

leftMargin

letterSpacing

noFallback

pixelsAboveLines

pixelsBelowLines

pixelsInsideWrap

rightMargin

tabs

wrapMode